@@ -97,11 +97,9 @@ dostandard(flames_frame *ScienceFrame,
 
     int actvals=0;
     char drs_verbosity[10];
-    int status=0;
 
     memset(drs_verbosity, 0, 10);
-    if ((status=SCKGETC(DRS_VERBOSITY, 1, 3, &actvals, drs_verbosity))
-                    != 0) {
+    if ( SCKGETC(DRS_VERBOSITY, 1, 3, &actvals, drs_verbosity) != 0) {
         /* the keyword seems undefined, protest... */
         return(MAREMMA);
     }
