@@ -559,8 +559,7 @@ BKGBADSCAN");
 
 
         /* read in the background table */
-        if ((status=readback(&(ScienceFrame->back), backfile, bxdegree, bydegree))
-                        != NOERR) {
+        if (NOERR !=readback(&(ScienceFrame->back), backfile, bxdegree, bydegree)) {
             /* something went wrong while reading the background table */
             sprintf(output, "Error %d while reading the background table", status);
             SCTPUT(output);
@@ -647,7 +646,7 @@ background", negativepixels);
         SCTPUT(output);
 
 
-        if ((status = readslitflats(slitsfile, Slit_FF)) != NOERR) {
+        if (NOERR != readslitflats(slitsfile, Slit_FF) ) {
             /* problems reading slitflats members from disk */
             SCTPUT("Error while reading the slit Flat Field frames");
             return flames_midas_fail();
@@ -885,7 +884,7 @@ table being used do not overlap at all!");
         /* let's read the slit FFs */
         sprintf(output, "I'm reading the slit FF frames");
         SCTPUT(output);
-        if ((status = readslitflats(slitsfile, Slit_FF)) != NOERR) {
+        if ( NOERR != readslitflats(slitsfile, Slit_FF) ) {
             /* problems reading slitflats members from disk */
             SCTPUT("Error while reading the slit Flat Field frames");
             return flames_midas_fail();
@@ -995,14 +994,13 @@ table being used do not overlap at all!");
         for (iframe=0; iframe<=(ScienceFrame->nflats-1); iframe++)
             ScienceFrame->yshift[iframe] = deltas[iframe];
         /* try to open the frame */
-        status = SCFOPN(ScienceFrame->framename, FLAMESDATATYPE, 0, F_IMA_TYPE,
-                        &fileid);
+        SCFOPN(ScienceFrame->framename, FLAMESDATATYPE, 0, F_IMA_TYPE,&fileid);
         nflats = (int) ScienceFrame->nflats;
-        status = SCDWRI(fileid, "NFLATS", &nflats, 1, 1, &unit);
-        status = SCDWRD(fileid, "YSHIFT", ScienceFrame->yshift, 1,
+        SCDWRI(fileid, "NFLATS", &nflats, 1, 1, &unit);
+        SCDWRD(fileid, "YSHIFT", ScienceFrame->yshift, 1,
                         (int) ScienceFrame->nflats, &unit);
 
-        status = SCFCLO(fileid) ;
+        SCFCLO(fileid) ;
     }
 
 
@@ -1123,7 +1121,7 @@ FF structure");
     sprintf(output, "I'm reading the slit FF frames");
     SCTPUT(output);
 
-    if ((status = readslitflats(slitsfile, Slit_FF)) != NOERR) {
+    if ( NOERR != readslitflats(slitsfile, Slit_FF) ) {
         /* problems reading slitflats members from disk */
         SCTPUT("Error while reading the slit Flat Field frames");
         return flames_midas_fail();
@@ -1174,8 +1172,7 @@ FF structure");
     if ((repeatflag!=0 ) && (bkginline == TRUE)) {
         /* read in the old background table */
         SCTPUT("A significant drift was detected:\n refit the background");
-        if ((status=readback(&(ScienceFrame->back), backfile, bxdegree, bydegree))
-                        != NOERR) {
+        if (NOERR !=readback(&(ScienceFrame->back), backfile, bxdegree, bydegree)) {
             /* something went wrong while reading the background table */
             sprintf(output, "Error %d while reading the background table", status);
             SCTPUT(output);
