@@ -75,8 +75,8 @@ int flames_mainstripfitsext(const char *FILENAME,
     int baselength=0;
     int unit=0;
 
-    filename = calloc(161, sizeof(char));
-    basename = calloc(161, sizeof(char));
+    filename = calloc(CATREC_LEN, sizeof(char));
+    basename = calloc(CATREC_LEN, sizeof(char));
 
     SCSPRO("stripfitsext"); /* Get into MIDAS Env. */
 
