@@ -441,7 +441,7 @@ if __name__ == '__main__':
   from flames_plot_common import *
 
   # Create interactive application
-  interactive_app = PipelineInteractiveApp()
+  interactive_app = PipelineInteractiveApp(enable_init_sop=True)
 
   #Check if import failed or not
   if import_sucess == 'false' :
