@@ -208,7 +208,7 @@ if __name__ == '__main__':
   import uves_plot_common
 
   # Create interactive application
-  interactive_app = reflex_interactive_app.PipelineInteractiveApp()
+  interactive_app = reflex_interactive_app.PipelineInteractiveApp(enable_init_sop=True)
 
   #Check if import failed or not
   if import_sucess == 'false' :
