@@ -1139,7 +1139,9 @@ unsigned int *uivector(nl,nh)
 
   v=(unsigned int *) calloc((unsigned int) (nh-nl+1+NR_END), 
 			    sizeof(unsigned int));
-  if (!v) nrerror("allocation failure in uivector()");
+  if (!v) {
+	  nrerror("allocation failure in uivector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1150,7 +1152,9 @@ char *cvector(nl,nh)
   char *v;
 
   v=(char *) calloc((unsigned int) (nh-nl+1+NR_END), sizeof(char));
-  if (!v) nrerror("allocation failure in cvector()");
+  if (!v) {
+	  nrerror("allocation failure in cvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1162,7 +1166,9 @@ char *ucvector(nl,nh)
 
   v=(unsigned char *) calloc((unsigned int) (nh-nl+1+NR_END), 
 			     sizeof(unsigned char));
-  if (!v) nrerror("allocation failure in ucvector()");
+  if (!v) {
+	  nrerror("allocation failure in ucvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1174,7 +1180,9 @@ int32_t *lvector(nl,nh)
 
   v=(int32_t *) calloc((unsigned int) (nh-nl+1+NR_END), 
 			sizeof(int32_t));
-  if (!v) nrerror("allocation failure in lvector()");
+  if (!v) {
+	  nrerror("allocation failure in lvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1186,7 +1194,9 @@ uint32_t *ulvector(nl,nh)
 
   v=(uint32_t*) calloc((unsigned int) (nh-nl+1+NR_END), 
 				sizeof(uint32_t));
-  if (!v) nrerror("allocation failure in ulvector()");
+  if (!v) {
+	  nrerror("allocation failure in ulvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1197,7 +1207,9 @@ double *dvector(nl,nh)
   double *v;
 
   v=(double *) calloc((unsigned int) (nh-nl+1+NR_END), sizeof(double));
-  if (!v) nrerror("allocation failure in dvector()");
+  if (!v) {
+	  nrerror("allocation failure in dvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1209,7 +1221,9 @@ double *fdvector(nl,nh)
 
   v=(frame_data *) calloc((unsigned int) (nh-nl+1+NR_END), 
 			  sizeof(frame_data));
-  if (!v) nrerror("allocation failure in dvector()");
+  if (!v) {
+	  nrerror("allocation failure in dvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1221,7 +1235,9 @@ double *fmvector(nl,nh)
 
   v=(frame_mask *) calloc((unsigned int) (nh-nl+1+NR_END), 
 			  sizeof(frame_mask));
-  if (!v) nrerror("allocation failure in dvector()");
+  if (!v) {
+	  nrerror("allocation failure in dvector()");
+  }
   return v-nl+NR_END;
 }
 
@@ -1234,14 +1250,18 @@ float **matrix(nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(float **) calloc((unsigned int)(nrow+NR_END), sizeof(float*));
-  if (!m) nrerror("allocation failure 1 in matrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in matrix()");
+  }
   m += NR_END;
   m -= nrl;
 
   /* allocate rows and set pointers to them */
   m[nrl]=(float *) calloc((unsigned int)(nrow*ncol+NR_END), 
 			  sizeof(float));
-  if (!m[nrl]) nrerror("allocation failure 2 in matrix()");
+  if (!m[nrl]) {
+	  nrerror("allocation failure 2 in matrix()");
+  }
   m[nrl] += NR_END;
   m[nrl] -= ncl;
 
@@ -1260,14 +1280,18 @@ char **cmatrix(nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(char **) calloc((unsigned int)(nrow+NR_END), sizeof(char*));
-  if (!m) nrerror("allocation failure 1 in cmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in cmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
   /* allocate rows and set pointers to them */
   m[nrl]=(char *) calloc((unsigned int)(nrow*ncol+NR_END), 
 			 sizeof(char));
-  if (!m[nrl]) nrerror("allocation failure 2 in cmatrix()");
+  if (!m[nrl]) {
+	  nrerror("allocation failure 2 in cmatrix()");
+  }
   m[nrl] += NR_END;
   m[nrl] -= ncl;
 
@@ -1286,7 +1310,9 @@ double **dmatrix(nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(double **) calloc((unsigned int)(nrow+NR_END), sizeof(double*));
-  if (!m) nrerror("allocation failure 1 in dmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in dmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1312,7 +1338,9 @@ int **imatrix(nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(int **) calloc((unsigned int)(nrow+NR_END), sizeof(int*));
-  if (!m) nrerror("allocation failure 1 in imatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in imatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1339,7 +1367,9 @@ uint32_t **ulmatrix(nrl,nrh,ncl,nch)
   /* allocate pointers to rows */
   m=(uint32_t **) calloc((unsigned int)(nrow+NR_END), 
 				  sizeof(uint32_t*));
-  if (!m) nrerror("allocation failure 1 in ulmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in ulmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1366,7 +1396,9 @@ int32_t **lmatrix(nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(int32_t **) calloc((unsigned int)(nrow+NR_END), sizeof(int32_t*));
-  if (!m) nrerror("allocation failure 1 in lmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in lmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1394,7 +1426,9 @@ frame_data **fdmatrix(nrl,nrh,ncl,nch)
   /* allocate pointers to rows */
   m=(frame_data **) calloc((unsigned int)(nrow+NR_END), 
 			   sizeof(frame_data*));
-  if (!m) nrerror("allocation failure 1 in fdmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in fdmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1422,7 +1456,9 @@ frame_mask **fmmatrix(nrl,nrh,ncl,nch)
   /* allocate pointers to rows */
   m=(frame_mask **) calloc((unsigned int)(nrow+NR_END), 
 			   sizeof(frame_mask*));
-  if (!m) nrerror("allocation failure 1 in fmmatrix()");
+  if (!m) {
+	  nrerror("allocation failure 1 in fmmatrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1450,7 +1486,9 @@ float **submatrix(a,oldrl,oldrh,oldcl,oldch,newrl,newcl)
 
   /* allocate array of pointers to rows */
   m=(float **) calloc((unsigned int) (nrow+NR_END), sizeof(float*));
-  if (!m) nrerror("allocation failure in submatrix()");
+  if (!m) {
+	  nrerror("allocation failure in submatrix()");
+  }
   m += NR_END;
   m -= newrl;
 
@@ -1474,7 +1512,9 @@ float **convert_matrix(a,nrl,nrh,ncl,nch)
 
   /* allocate pointers to rows */
   m=(float **) calloc((unsigned int) (nrow+NR_END), sizeof(float*));
-  if (!m)    nrerror("allocation failure in convert_matrix()");
+  if (!m)    {
+	  nrerror("allocation failure in convert_matrix()");
+  }
   m += NR_END;
   m -= nrl;
 
@@ -1494,7 +1534,9 @@ float ***f3tensor(nrl,nrh,ncl,nch,ndl,ndh)
 
   /* allocate pointers to pointers to rows */
   t=(float ***) calloc((unsigned int)(nrow+NR_END), sizeof(float**));
-  if (!t) nrerror("allocation failure 1 in f3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in f3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1533,7 +1575,9 @@ frame_data ***fd3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(frame_data ***) calloc((unsigned int)(nrow+NR_END), 
 			    sizeof(frame_data**));
-  if (!t) nrerror("allocation failure 1 in fd3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in fd3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1571,7 +1615,9 @@ double ***d3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   double ***t;
 
   /* allocate pointers to pointers to rows */
-  t=(double ***) calloc((unsigned int)(nrow+NR_END), sizeof(double**));
+  t=(double ***) {
+	  calloc((unsigned int)(nrow+NR_END), sizeof(double**));
+  }
   if (!t) nrerror("allocation failure 1 in d3tensor()");
   t += NR_END;
   t -= nrl;
@@ -1611,7 +1657,9 @@ frame_data ***fd3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(frame_data ***) calloc((unsigned int)(nrow+NR_END), 
 			    sizeof(frame_data**));
-  if (!t) nrerror("allocation failure 1 in f3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in f3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1651,7 +1699,9 @@ frame_mask ***fm3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(frame_mask ***) calloc((unsigned int)(nrow+NR_END), 
 			    sizeof(frame_mask**));
-  if (!t) nrerror("allocation failure 1 in f3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in f3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1691,7 +1741,9 @@ uint32_t ***ul3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(uint32_t ***) calloc((unsigned int)(nrow+NR_END), 
 				   sizeof(uint32_t**));
-  if (!t) nrerror("allocation failure 1 in f3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in f3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1731,7 +1783,9 @@ int32_t ***l3tensor(nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(int32_t ***) calloc((unsigned int)(nrow+NR_END), 
 			  sizeof(int32_t**));
-  if (!t) nrerror("allocation failure 1 in f3tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in f3tensor()");
+  }
   t += NR_END;
   t -= nrl;
 
@@ -1771,7 +1825,9 @@ int32_t ***l4tensor(nal,nah,nrl,nrh,ncl,nch,ndl,ndh)
   /* allocate pointers to pointers to rows */
   t=(int32_t ****) calloc((unsigned int)(na+NR_END), 
 			   sizeof(int32_t***));
-  if (!t) nrerror("allocation failure 1 in l4tensor()");
+  if (!t) {
+	  nrerror("allocation failure 1 in l4tensor()");
+  }
   t += NR_END;
   t -= nal;
 
