@@ -22,163 +22,6 @@
  * $Date: 2011-01-03 08:39:09 $
  * $Revision: 1.53 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.52  2010/12/16 16:57:40  amodigli
- * fixed compiler warnings
- *
- * Revision 1.51  2010/09/27 06:32:41  amodigli
- * fixed mem leaks
- *
- * Revision 1.50  2010/09/24 09:32:03  amodigli
- * put back QFITS dependency to fix problem spot by NRI on FIBER mode (with MIDAS calibs) data
- *
- * Revision 1.48  2010/06/11 11:40:00  amodigli
- * add uves_qcdark_define_parameters_body(), uves_mdark_define_qc_parameters()
- *
- * Revision 1.47  2010/06/08 13:51:55  amodigli
- * cleaned output
- *
- * Revision 1.46  2010/05/14 12:47:40  amodigli
- * set range on several params that control QC
- *
- * Revision 1.45  2010/05/11 05:49:02  amodigli
- * clarified recipe help
- *
- * Revision 1.44  2010/03/24 14:56:30  amodigli
- * fixed compiler warning
- *
- * Revision 1.43  2010/03/22 15:57:43  amodigli
- * added params and possibility to compute master as mean stack
- *
- * Revision 1.42  2010/03/01 18:00:22  amodigli
- * fixed several bugs in computing QC parameters
- *
- * Revision 1.41  2008/11/06 14:36:27  amodigli
- * fixed mem leaks
- *
- * Revision 1.40  2008/09/29 06:57:03  amodigli
- * add #include <string.h>
- *
- * Revision 1.39  2008/03/28 08:53:50  amodigli
- * IRPLIB_CONCAT2X-->UVES_CONCAT2X
- *
- * Revision 1.38  2008/02/15 12:43:49  amodigli
- * allow lower/upper chip for parameter process_chip
- *
- * Revision 1.37  2007/10/05 16:01:45  amodigli
- * using proces_chip parameter to process or not a given RED chip
- *
- * Revision 1.36  2007/08/31 06:27:02  amodigli
- * include uves_globals.h
- *
- * Revision 1.35  2007/08/24 08:28:36  amodigli
- * clearer parm doc
- *
- * Revision 1.34  2007/08/24 06:55:36  amodigli
- * fixed parameter io for qc
- *
- * Revision 1.33  2007/08/21 13:08:26  jmlarsen
- * Removed irplib_access module, largely deprecated by CPL-4
- *
- * Revision 1.32  2007/08/17 10:07:02  amodigli
- * added QC params asked by DFS04195
- *
- * Revision 1.31  2007/06/11 13:28:26  jmlarsen
- * Changed recipe contact address to cpl at eso.org
- *
- * Revision 1.30  2007/06/08 13:06:16  jmlarsen
- * Send bug reports to Andrea
- *
- * Revision 1.29  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.28  2007/05/16 09:50:40  jmlarsen
- * Do not threshold to zero after bias subtraction
- *
- * Revision 1.27  2007/04/24 12:50:29  jmlarsen
- * Replaced cpl_propertylist -> uves_propertylist which is much faster
- *
- * Revision 1.26  2007/02/09 13:37:47  jmlarsen
- * Enable calling from uves_cal_mkmaster
- *
- * Revision 1.25  2007/02/09 08:57:44  jmlarsen
- * Include <float.h>
- *
- * Revision 1.24  2007/02/09 08:14:16  jmlarsen
- * Do not use CPL_PIXEL_MAXVAL which works only for integer images
- *
- * Revision 1.23  2006/12/07 08:23:23  jmlarsen
- * uves_load_raw_imagelist: support FLAMES
- *
- * Revision 1.22  2006/11/15 15:02:14  jmlarsen
- * Implemented const safe workarounds for CPL functions
- *
- * Revision 1.20  2006/11/15 14:04:08  jmlarsen
- * Removed non-const version of parameterlist_get_first/last/next which is
- * already in CPL, added const-safe wrapper, unwrapper and deallocator functions
- *
- * Revision 1.19  2006/11/06 15:19:41  jmlarsen
- * Removed unused include directives
- *
- * Revision 1.18  2006/10/17 12:33:02  jmlarsen
- * Added semicolon at UVES_RECIPE_DEFINE invocation
- *
- * Revision 1.17  2006/10/09 13:01:13  jmlarsen
- * Use macro to define recipe interface functions
- *
- * Revision 1.16  2006/09/19 14:31:17  jmlarsen
- * uves_insert_frame(): use bitmap to specify which image statistics keywords must be computed
- *
- * Revision 1.15  2006/09/19 06:55:55  jmlarsen
- * Changed interface of uves_frameset to optionally write image statistics kewwords
- *
- * Revision 1.14  2006/08/24 11:36:37  jmlarsen
- * Write recipe start/stop time to header
- *
- * Revision 1.13  2006/08/17 13:56:53  jmlarsen
- * Reduced max line length
- *
- * Revision 1.12  2006/08/11 14:56:05  amodigli
- * removed Doxygen warnings
- *
- * Revision 1.11  2006/07/14 12:19:28  jmlarsen
- * Support multiple QC tests per product
- *
- * Revision 1.10  2006/07/03 13:02:18  jmlarsen
- * Threshold to zero after bias subtraction
- *
- * Revision 1.9  2006/06/28 13:29:06  amodigli
- * removed TEST ID from QC log
- *
- * Revision 1.8  2006/06/16 08:25:45  jmlarsen
- * Manually propagate ESO.DET. keywords from 1st/2nd input header
- *
- * Revision 1.7  2006/06/13 11:57:02  jmlarsen
- * Check that calibration frames are from the same chip ID
- *
- * Revision 1.6  2006/06/01 14:43:17  jmlarsen
- * Added missing documentation
- *
- * Revision 1.5  2006/05/09 07:42:18  amodigli
- * added QC-LOG
- *
- * Revision 1.4  2006/04/06 12:57:22  jmlarsen
- * Added support for PDARK, MASTER_PDARK frames
- *
- * Revision 1.3  2006/04/06 09:48:15  amodigli
- * changed uves_frameset_insert interface to have QC log
- *
- * Revision 1.2  2006/04/06 08:37:33  jmlarsen
- * Removed memory leak
- *
- * Revision 1.1  2006/02/03 07:46:30  jmlarsen
- * Moved recipe implementations to ./uves directory
- *
- * Revision 1.27  2006/01/19 08:47:24  jmlarsen
- * Insertedv missing doxygen end tag
- *
- * Revision 1.26  2005/12/19 16:17:55  jmlarsen
- * Replaced bool -> int
  *
  */
 
@@ -396,14 +239,15 @@ cpl_error_code
 uves_mdark_define_qc_parameters(cpl_parameterlist* parameters)
 {
   
-    const char *name = "";
-    char *full_name = NULL;
-    cpl_parameter *p = NULL;
+
+
     
+
     {
    
-      name = "reg.num_x";
-      full_name = uves_sprintf("%s.%s", UVES_QCDARK_ID, name);
+      const char* name = "reg.num_x";
+      char* full_name = uves_sprintf("%s.%s", UVES_QCDARK_ID, name);
+      cpl_parameter *p = NULL;
       uves_parameter_new_range(p, full_name,
 			       CPL_TYPE_INT,
 			       "Number of regions along the X axis "
@@ -648,7 +492,7 @@ uves_mdark_process_chip(const cpl_imagelist *raw_images,
             uves_msg("Skipping bias subtraction");
         }
         
-        check( exposure_time = uves_pfits_get_exptime(current_header), 
+         check( exposure_time = uves_pfits_get_exptime(current_header),
            "Error reading exposure time");
 
         if(pr_num_x != 0 && pr_num_y != 0 && pr_box_sx != 0 && pr_box_sy !=0 ) {
@@ -712,6 +556,7 @@ uves_mdark_process_chip(const cpl_imagelist *raw_images,
     } 
     check( uves_pfits_set_exptime(mdark_header, (max_exptime + min_exptime)/2),
        "Error setting master dark exposure time");
+    uves_pfits_set_extname(mdark_header,"Master dark");
     
   cleanup:
     uves_free_image(&current_dark);
